@@ -1,8 +1,9 @@
 from libspn_keras.initializers.epsilon_inverse_fan_in import EpsilonInverseFanIn
 from libspn_keras.initializers.equidistant import Equidistant
 from libspn_keras.initializers.poon_domingos import PoonDomingosMeanOfQuantileSplit
+from libspn_keras.initializers.kmeans import KMeans
 
 __all__ = [
-    'EpsilonInverseFanIn', 'Equidistant', 'PoonDomingosMeanOfQuantileSplit'
+    'EpsilonInverseFanIn', 'Equidistant', 'PoonDomingosMeanOfQuantileSplit', 'KMeans'
 ]
 
